==> nextcloud-14.0.1.tgz: nextcloud/apps/gallery/l10n/bg.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "Галерия",
    "Aborting preview. Could not find the file" : "Прекратяване на прегледа. Файлът не може да бъде намерен",
    "Could not load the description" : "Описанието не може да бъде заредено",
    "Could not load the description: " : "Описанието не може да бъде заредено:",
    "Copyright" : "Авторско право",
    "Could not load the copyright notice: " : "Неможе да се зареди известието за авторско право:",
    "Copyright notice" : "Известие за авторско право ",
    "Link to copyright document" : "Препратка към документа с авторските права",
    "This application may not work properly on your browser." : "Приложението може да не работи правилно във вашият браузър.",
    "For an improved experience, please install one of the following alternatives" : "За подобрен опит, моля инсталирайте една от следните алтернативи",
    "Your browser is not supported!" : "Вашият браузър не се поддържа!",
    "please install one of the following alternatives" : "моля инсталирайте една от следните алтернативи",
    "No media files found" : "Не са открити медийни файлове",
    "Configuration error" : "Конфигурационна грешка",
    "New" : "Създай",
    "Hide Album" : "Скрий албум",
    "Error loading slideshow template" : "Грешка при зареждане на шаблон за слайдшоу.",
    "Next" : "Следваща",
    "Play" : "Пусни",
    "Pause" : "Пауза",
    "Previous" : "Предишна",
    "Close" : "Затвори",
    "Download" : "Изтегляне",
    "Toggle background" : "Превключване на фона",
    "Delete" : "Изтриване",
    "Share" : "Сподели",
    "\"{name}\" is an invalid file name." : "\"{name}\" е непозволено име за файл.",
    "File name cannot be empty." : "Името на файла не може да бъде празно.",
    "Upload" : "Качване",
    "Error" : "Грешка",
    "Error while sharing" : "Грешка при споделяне",
    "Error while unsharing" : "Грешка при премахване на споделянето",
    "Error while changing permissions" : "Грешка при промяна на правата",
    "Shared with you and the group {group} by {owner}" : "Споделено с вас и групата {group} от {owner}",
    "Shared with you by {owner}" : "Споделено с Вас от {owner}.",
    "Share with users or groups …" : "Споделяне с потребители или групи...",
    "Share with users, groups or remote users …" : "Споделяне с потребители, групи или отдалечени потребители...",
    "Share link" : "Връзка за споделяне",
    "The public link will expire no later than {days} days after it is created" : "Общодостъпната връзка ще изтече не по-късно от {days} дни след създаването ѝ.",
    "Link" : "Връзка",
    "Password protect" : "Защитено с парола",
    "Password" : "Парола",
    "Choose a password for the public link" : "Изберете парола за общодостъпната връзка",
    "Allow editing" : "Позволяване на редактиране",
    "Email link to person" : "Имейл връзка към човек",
    "Send" : "Изпращане",
    "Set expiration date" : "Задаване на дата на изтичане",
    "Expiration" : "Изтичане",
    "Expiration date" : "Дата на изтичане",
    "Adding user..." : "Добавяне на потребител...",
    "group" : "група",
    "remote" : "отдалечен",
    "Resharing is not allowed" : "Повторно споделяне не е разрешено.",
    "Unshare" : "Прекратяване на споделяне",
    "notify by email" : "уведомяване по електронна поща",
    "can share" : "може да споделя",
    "can edit" : "може да променя",
    "access control" : "контрол на достъпа",
    "create" : "създаване",
    "change" : "промяна",
    "delete" : "изтриване",
    "Password protected" : "Защитено с парола",
    "Error unsetting expiration date" : "Грешка при премахване на дата на изтичане",
    "Error setting expiration date" : "Грешка при настройване на датата за изтичане",
    "Email sent" : "Електронната поща е изпратена",
    "Warning" : "Предупреждение",
    "Add to your Nextcloud" : "Добавете към вашия Nextcloud",
    "This share is password-protected" : "Тази зона е защитена с парола.",
    "The password is wrong. Try again." : "Грешна парола. Опитайте отново.",
    "Sort by name" : "Сортирай по име",
    "Sort by date" : "Сортирай по дата",
    "Cancel upload" : "Отказване на качването",
    "Album information" : "Информация за албума",
    "File list" : "Списък с файлове",
    "Sorry, this file could not be found." : "За съжаление този файл не може да бъде намерен.",
    "Reasons might be:" : "Причините може да са:",
    "the wrong file ID was provided" : "предоставен е грешен ID на файл",
    "the file was removed" : "файлът беше премахнат",
    "the file is corrupt" : "файлът е повреден",
    "the encryption key is missing" : "криптиращия ключ липсва",
    "Here is the error message returned by the server: " : "Ето съобщението за грешка, върнато от сървъра:",
    "For more information, please contact your friendly Nextcloud administrator." : "За повече информация се свържете с любезния администратор на Nextcloud.",
    "Sorry, but the server could not fulfill your request." : "Съжаляваме, но сървърът не може да изпълни заявката.",
    "Possible reasons for the problem:" : "Възможни причини за проблема:",
    "a conflicting app was installed" : "бе инсталирано конфликтно приложение",
    "a required component is missing or was disconnected" : "необходимият компонент липсва или е бил премахнат",
    "the filesystem is not readable" : "файловата система не е четима",
    "Sorry, this link doesn't seem to work anymore." : "Съжаляваме, тази връзка не изглежда да работи повече.",
    "the item was removed" : "съдържанието е премахнато",
    "the link has expired" : "тази връзка е изтекла",
    "sharing is disabled" : "споделянето е изключено",
    "For more information, please ask the person who has sent you this link." : "За повече информация, моля обърнете се към човека, който ви е изпратил тази връзка.",
    "Picture view" : "Албум със снимки",
    "An error occured. Please try again" : "Възникна грешка. Опитайте отново.",
    "Sending ..." : "Изпращане ..."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-15.0.5p1.tgz: nextcloud/apps/gallery/l10n/bg.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "Галерия",
    "There was a problem reading files from this album" : "Възникна проблем с четенето на файлове от този албум",
    "Aborting preview. Could not find the file" : "Прекратяване на прегледа. Файлът не може да бъде намерен",
    "Could not move \"{file}\", target exists" : "Файлът \"{file}\" не може да бъде преместен, дестинацията съществува",
    "Could not move \"{file}\"" : "Файл \"{file}\" не можа да бъде преместен",
    "No compatible server found at {remote}" : "Не беше намерен съвместим сървър на {remote}",
    "Invalid server url" : "URL адреса на сървъра не е валиден",
    "Could not load the description" : "Описанието не може да бъде заредено",
    "Could not load the description: " : "Описанието не може да бъде заредено:",
    "Copyright" : "Авторско право",
    "Could not load the copyright notice: " : "Неможе да се зареди известието за авторско право:",
    "Copyright notice" : "Известие за авторско право ",
    "Link to copyright document" : "Връзка към документа с авторските права",
    "This application may not work properly on your browser." : "Приложението може да не работи правилно във вашият браузър.",
    "For an improved experience, please install one of the following alternatives" : "За подобрен опит, моля инсталирайте една от следните алтернативи",
    "Your browser is not supported!" : "Вашият браузър не се поддържа!",
    "please install one of the following alternatives" : "моля инсталирайте една от следните алтернативи",
    "Album cannot be shown" : "Албума не може да бъде показан",
    "No media files found" : "Не са открити медийни файлове",
    "Upload pictures in the Files app to display them here" : "Качете снимки в Файловото приложение за да се визуализират тук",
    "Upload new files via drag and drop or by using the [+] button above" : "Качете нови файлове чрез довличане или чрез използване на [+] бутона отгоре",
    "Configuration error" : "Конфигурационна грешка",
    "Hide Album" : "Скрий албум",
    "Could not hide album" : "Албума не можа да бъде скрит",
    "Error loading slideshow template" : "Грешка при зареждане на шаблон за слайдшоу.",
    "<strong>Error!</strong> Could not generate a preview of this file.<br>Please go to the next slide while we remove this image from the slideshow" : "<strong>Грешка!</strong> Не можа да бъде генериран преглед на този файл.<br> Моля, отидете на следващия слайд докато премахнете това изображение от слайд шоуто",
    "Next" : "Следваща",
    "Play" : "Пусни",
    "Pause" : "Пауза",
    "Previous" : "Предишна",
    "Close" : "Затвори",
    "Download" : "Изтегляне",
    "Toggle background" : "Превключване на фона",
    "Delete" : "Изтриване",
    "Share" : "Сподели",
    "Could not create file \"{file}\" because it already exists" : "Файл \"{file}\" не може да бъде създаден, защото вече съществува",
    "Could not create file \"{file}\"" : "Файл \"{file}\" не може да бъде създаден",
    "\"{name}\" is an invalid file name." : "\"{name}\" е непозволено име за файл.",
    "File name cannot be empty." : "Името на файла не може да бъде празно.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" не е разрешен файлов туп",
    "Upload" : "Качване",
    "Error" : "Грешка",
    "Error while sharing" : "Грешка при споделяне",
    "Error while unsharing" : "Грешка при премахване на споделянето",
    "Error while changing permissions" : "Грешка при промяна на правата",
    "Shared with you and the group {group} by {owner}" : "Споделено с вас и групата {group} от {owner}",
    "Shared with you by {owner}" : "Споделено с Вас от {owner}.",
    "Share with users or groups …" : "Споделяне с потребители или групи...",
    "Share with users, groups or remote users …" : "Споделяне с потребители, групи или отдалечени потребители...",
    "Share link" : "Връзка за споделяне",
    "The public link will expire no later than {days} days after it is created" : "Общодостъпната връзка ще изтече не по-късно от {days} дни след създаването ѝ.",
    "Link" : "Връзка",
    "Password protect" : "Защитено с парола",
    "Password" : "Парола",
    "Choose a password for the public link" : "Изберете парола за общодостъпната връзка",
    "Allow editing" : "Позволяване на редактиране",
    "Email link to person" : "Имейл връзка към човек",
    "Send" : "Изпращане",
    "Set expiration date" : "Срок на валидност",
    "Expiration" : "Изтичане",
    "Expiration date" : "Дата на изтичане",
    "This list is maybe truncated - please refine your search term to see more results." : "Този списък може да е съкратен, моля рафинирайте параметрите на търсене за повече резултати.",
    "No users or groups found for {search}" : "Няма намерени потребители или групи намерени за {search}",
    "No users found for {search}" : "Няма намерени потребители за {search}",
    "An error occurred (\"{message}\"). Please try again" : "Възникна грешка (\"{message}\"). Моля, опитайте отново",
    "An error occurred. Please try again" : "Възникан грешка. Моля, опитайте отново",
    "Adding user..." : "Добавяне на потребител...",
    "group" : "група",
    "remote" : "отдалечен",
    "Resharing is not allowed" : "Повторното споделяне е забранено",
    "Error while retrieving shares" : "Грешка при вземане на дялове",
    "Unshare" : "Прекратяване на споделяне",
    "notify by email" : "уведомяване по електронна поща",
    "can share" : "може да споделя",
    "can edit" : "може да редактира",
    "access control" : "контрол на достъпа",
    "create" : "създаване",
    "change" : "промяна",
    "delete" : "изтриване",
    "Password protected" : "Защитено с парола",
    "Error unsetting expiration date" : "Грешка при премахване на дата на изтичане",
    "Error setting expiration date" : "Грешка при задаване на срок на валидност",
    "Sending…" : "Изпращане...",
    "Email sent" : "Електронната поща е изпратена",
    "Warning" : "Предупреждение",
    "shared by %s" : "споделено от %s",
    "Direct link" : "Директен линк",
    "Add to your Nextcloud" : "Добавете към вашия Nextcloud",
    "Media gallery for Nextcloud" : "Галерия за Nextcloud",
    "This share is password-protected" : "Тази зона е защитена с парола.",
    "The password is wrong. Try again." : "Грешна парола. Опитайте отново.",
    "Sort by name" : "Сортирай по име",
    "Sort by date" : "Сортирай по дата",
    "Cancel upload" : "Откажи качването",
    "Album information" : "Информация за албума",
    "File list" : "Списък с файлове",
    "Sorry, this file could not be found." : "За съжаление този файл не може да бъде намерен.",
    "Reasons might be:" : "Причините може да са:",
    "the wrong file ID was provided" : "предоставен е грешен ID на файл",
    "the file was removed" : "файлът беше премахнат",
    "the file is corrupt" : "файлът е повреден",
    "the encryption key is missing" : "криптиращия ключ липсва",
    "Here is the error message returned by the server: " : "Ето съобщението за грешка, върнато от сървъра:",
    "For more information, please contact your friendly Nextcloud administrator." : "За допълнителна информация се свържете с любезния администратор на Nextcloud.",
    "Sorry, but the server could not fulfill your request." : "Съжаляваме, но сървърът не може да изпълни заявката.",
    "Possible reasons for the problem:" : "Възможни причини за проблема:",
    "a conflicting app was installed" : "бе инсталирано конфликтно приложение",
    "a required component is missing or was disconnected" : "необходимият компонент липсва или е бил премахнат",
    "the filesystem is not readable" : "файловата система не е четима",
    "Sorry, this link doesn't seem to work anymore." : "Съжаляваме, тази връзка не изглежда да работи повече.",
    "the item was removed" : "съдържанието е премахнато",
    "the link has expired" : "тази връзка е изтекла",
    "sharing is disabled" : "споделянето е изключено",
    "For more information, please ask the person who has sent you this link." : "За допълнителна информация, моля обърнете се към човека, който ви е изпратил тази връзка.",
    "Picture view" : "Албум със снимки",
    "New" : "Създай",
    "Share with people on other servers using their Federated Cloud ID username@example.com/cloud" : "Споделете с хора на други сървъри чрез Federated Cloud ID username@example.com/cloud",
    "An error occured. Please try again" : "Възникна грешка. Опитайте отново.",
    "Sending ..." : "Изпращане ..."
},
"nplurals=2; plural=(n != 1);");
